@@ -3,274 +3,270 @@ from DobotRPC import DobotlinkAdapter, RPCClient
 
 class M1Api(object):
     def __init__(self):
-        self.__port_name: str
         self.__dobotlink = DobotlinkAdapter(RPCClient(), is_sync=True)
 
-    def set_portname(self, port_name):
-        self.__port_name = port_name
-
     def search_dobot(self):
         return self.__dobotlink.M1.SearchDobot()
 
-    def connect_dobot(self, queue_start=True):
-        return self.__dobotlink.M1.ConnectDobot(portName=self.__port_name,
+    def connect_dobot(self, port_name, queue_start=True):
+        return self.__dobotlink.M1.ConnectDobot(portName=port_name,
                                                 queueStart=queue_start)
 
-    def disconnect_dobot(self, queue_stop=True, queue_clear=True):
-        return self.__dobotlink.M1.DisconnectDobot(portName=self.__port_name,
+    def disconnect_dobot(self, port_name, queue_stop=True, queue_clear=True):
+        return self.__dobotlink.M1.DisconnectDobot(portName=port_name,
                                                    queueStop=queue_stop,
                                                    queueClear=queue_clear)
 
-    def get_devicesn(self, ):
-        return self.__dobotlink.M1.GetDeviceSN(portName=self.__port_name, )
+    def get_devicesn(self, port_name):
+        return self.__dobotlink.M1.GetDeviceSN(portName=port_name)
 
-    def set_devicename(self, device_name):
-        return self.__dobotlink.M1.SetDeviceName(portName=self.__port_name,
+    def set_devicename(self, port_name, device_name):
+        return self.__dobotlink.M1.SetDeviceName(portName=port_name,
                                                  deviceName=device_name)
 
-    def get_devicename(self, ):
-        return self.__dobotlink.M1.GetDeviceName(portName=self.__port_name, )
+    def get_devicename(self, port_name):
+        return self.__dobotlink.M1.GetDeviceName(portName=port_name)
 
-    def get_deviceversion(self, get_type: int):
-        return self.__dobotlink.M1.GetDeviceVersion(portName=self.__port_name,
+    def get_deviceversion(self, port_name, get_type: int):
+        return self.__dobotlink.M1.GetDeviceVersion(portName=port_name,
                                                     type=get_type)
 
-    def get_hardware_version(self, ):
+    def get_hardware_version(self, port_name):
         return self.__dobotlink.M1.GetHardwareVersion(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def queuedcmd_start(self, ):
-        return self.__dobotlink.M1.QueuedCmdStart(portName=self.__port_name, )
+    def queuedcmd_start(self, port_name):
+        return self.__dobotlink.M1.QueuedCmdStart(portName=port_name)
 
-    def queuedcmd_stop(self, force_stop=False):
-        return self.__dobotlink.M1.QueuedCmdStop(portName=self.__port_name,
+    def queuedcmd_stop(self, port_name, force_stop=False):
+        return self.__dobotlink.M1.QueuedCmdStop(portName=port_name,
                                                  forceStop=force_stop)
 
-    def queuedcmd_clear(self, ):
-        return self.__dobotlink.M1.QueuedCmdClear(portName=self.__port_name, )
+    def queuedcmd_clear(self, port_name):
+        return self.__dobotlink.M1.QueuedCmdClear(portName=port_name)
 
-    def queuedcmd_startdownload(self, total_loop, lineper_loop):
+    def queuedcmd_startdownload(self, port_name, total_loop, lineper_loop):
         return self.__dobotlink.M1.QueuedCmdStartDownload(
-            portName=self.__port_name,
+            portName=port_name,
             totalLoop=total_loop,
             linePerLoop=lineper_loop)
 
-    def queuedcmd_stopdownload(self, ):
+    def queuedcmd_stopdownload(self, port_name):
         return self.__dobotlink.M1.QueuedCmdStopDownload(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_queuedcmd_currentindex(self, ):
+    def get_queuedcmd_currentindex(self, port_name):
         return self.__dobotlink.M1.GetQueuedCmdCurrentIndex(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_queuedcmd_leftspace(self, ):
+    def get_queuedcmd_leftspace(self, port_name):
         return self.__dobotlink.M1.GetQueuedCmdLeftSpace(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_pose(self, ):
-        return self.__dobotlink.M1.GetPose(portName=self.__port_name, )
+    def get_pose(self, port_name):
+        return self.__dobotlink.M1.GetPose(portName=port_name)
 
-    def reset_pose(self, front_angle1, front_angle2):
-        return self.__dobotlink.M1.ResetPose(portName=self.__port_name,
+    def reset_pose(self, port_name, front_angle1, front_angle2):
+        return self.__dobotlink.M1.ResetPose(portName=port_name,
                                              frontAngle1=front_angle1,
                                              frontAngle2=front_angle2)
 
-    def set_usercoordinate(self,
+    def set_usercoordinate(self, port_name,
                            x: float,
                            y: float,
                            z: float,
                            r: float,
                            is_queued=False):
-        return self.__dobotlink.M1.SetUserCoordinate(portName=self.__port_name,
+        return self.__dobotlink.M1.SetUserCoordinate(portName=port_name,
                                                      x=x,
                                                      y=y,
                                                      z=z,
                                                      r=r,
                                                      isQueued=is_queued)
 
-    def get_usercoordinate(self, ):
+    def get_usercoordinate(self, port_name):
         return self.__dobotlink.M1.GetUserCoordinate(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_toolcoordinate(self,
+    def set_toolcoordinate(self, port_name,
                            x: float,
                            y: float,
                            z: float,
                            r: float,
                            is_queued=False):
-        return self.__dobotlink.M1.SetToolCoordinate(portName=self.__port_name,
+        return self.__dobotlink.M1.SetToolCoordinate(portName=port_name,
                                                      x=x,
                                                      y=y,
                                                      z=z,
                                                      r=r,
                                                      isQueued=is_queued)
 
-    def get_toolcoordinate(self, ):
+    def get_toolcoordinate(self, port_name):
         return self.__dobotlink.M1.GetToolCoordinate(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_alarms_state(self, ):
-        return self.__dobotlink.M1.GetAlarmsState(portName=self.__port_name, )
+    def get_alarms_state(self, port_name):
+        return self.__dobotlink.M1.GetAlarmsState(portName=port_name)
 
-    def clear_allalarms_state(self, ):
+    def clear_allalarms_state(self, port_name):
         return self.__dobotlink.M1.ClearAllAlarmsState(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_run_state(self, ):
-        return self.__dobotlink.M1.GetRunState(portName=self.__port_name, )
+    def get_run_state(self, port_name):
+        return self.__dobotlink.M1.GetRunState(portName=port_name)
 
-    def set_homecmd(self,
+    def set_homecmd(self, port_name,
                     is_resetpars=False,
                     is_queued=True,
                     iswait_forfinish=True,
                     time_out=25000):
-        return self.__dobotlink.M1.SetHOMECmd(portName=self.__port_name,
+        return self.__dobotlink.M1.SetHOMECmd(portName=port_name,
                                               isResetPars=is_resetpars,
                                               isQueued=is_queued,
                                               isWaitForFinish=iswait_forfinish,
                                               timeout=time_out)
 
-    def set_home_initialpos(self, ):
+    def set_home_initialpos(self, port_name):
         return self.__dobotlink.M1.SetHOMEInitialPos(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_hhttrig_mode(self, mode: int, is_queued=False):
-        return self.__dobotlink.M1.SetHHTTrigMode(portName=self.__port_name,
+    def set_hhttrig_mode(self, port_name, mode: int, is_queued=False):
+        return self.__dobotlink.M1.SetHHTTrigMode(portName=port_name,
                                                   mode=mode,
                                                   isQueued=is_queued)
 
-    def get_hhttrig_mode(self, ):
-        return self.__dobotlink.M1.GetHHTTrigMode(portName=self.__port_name, )
+    def get_hhttrig_mode(self, port_name):
+        return self.__dobotlink.M1.GetHHTTrigMode(portName=port_name)
 
-    def set_hhttrig_output_enabled(self, enable: bool, is_queued=False):
+    def set_hhttrig_output_enabled(self, port_name, enable: bool, is_queued=False):
         return self.__dobotlink.M1.SetHHTTrigOutputEnabled(
-            portName=self.__port_name, enable=enable, isQueued=is_queued)
+            portName=port_name, enable=enable, isQueued=is_queued)
 
-    def get_hhttrig_output_enabled(self, ):
+    def get_hhttrig_output_enabled(self, port_name):
         return self.__dobotlink.M1.GetHHTTrigOutputEnabled(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_hhttrig_output(self, ):
+    def get_hhttrig_output(self, port_name):
         return self.__dobotlink.M1.GetHHTTrigOutput(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_servo_power(self, on: bool, is_queued=False):
-        return self.__dobotlink.M1.SetServoPower(portName=self.__port_name,
+    def set_servo_power(self, port_name, on: bool, is_queued=False):
+        return self.__dobotlink.M1.SetServoPower(portName=port_name,
                                                  on=on,
                                                  isQueued=is_queued)
 
-    def set_endeffector_params(self,
+    def set_endeffector_params(self, port_name,
                                x_offset: float,
                                y_offset: float,
                                z_offset: float,
                                is_queued=False):
         return self.__dobotlink.M1.SetEndEffectorParams(
-            portName=self.__port_name,
+            portName=port_name,
             xOffset=x_offset,
             yOffset=y_offset,
             zOffset=z_offset,
             isQueued=is_queued)
 
-    def get_endeffector_params(self, ):
+    def get_endeffector_params(self, port_name):
         return self.__dobotlink.M1.GetEndEffectorParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_endeffector_laser(self, enable: bool, on: bool, is_queued=False):
+    def set_endeffector_laser(self, port_name, enable: bool, on: bool, is_queued=False):
         return self.__dobotlink.M1.SetEndEffectorLaser(
-            portName=self.__port_name,
+            portName=port_name,
             enable=enable,
             on=on,
             isQueued=is_queued)
 
-    def get_endeffector_laser(self, ):
+    def get_endeffector_laser(self, port_name):
         return self.__dobotlink.M1.GetEndEffectorLaser(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_endeffector_suctioncup(self,
+    def set_endeffector_suctioncup(self, port_name,
                                    enable: bool,
                                    on: bool,
                                    is_queued=False):
         return self.__dobotlink.M1.SetEndEffectorSuctionCup(
-            portName=self.__port_name,
+            portName=port_name,
             enable=enable,
             on=on,
             isQueued=is_queued)
 
-    def get_endeffector_suctioncup(self, ):
+    def get_endeffector_suctioncup(self, port_name):
         return self.__dobotlink.M1.GetEndEffectorSuctionCup(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_endeffector_gripper(self, enable: bool, on: bool, is_queued=False):
+    def set_endeffector_gripper(self, port_name, enable: bool, on: bool, is_queued=False):
         return self.__dobotlink.M1.SetEndEffectorGripper(
-            portName=self.__port_name,
+            portName=port_name,
             enable=enable,
             on=on,
             isQueued=is_queued)
 
-    def get_endeffector_gripper(self, ):
+    def get_endeffector_gripper(self, port_name):
         return self.__dobotlink.M1.GetEndEffectorGripper(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_jogjoint_params(self, velocity, acceleration, is_queued=False):
-        return self.__dobotlink.M1.SetJOGJointParams(portName=self.__port_name,
+    def set_jogjoint_params(self, port_name, velocity, acceleration, is_queued=False):
+        return self.__dobotlink.M1.SetJOGJointParams(portName=port_name,
                                                      velocity=velocity,
                                                      acceleration=acceleration,
                                                      isQueued=is_queued)
 
-    def get_jogjoint_params(self, ):
+    def get_jogjoint_params(self, port_name):
         return self.__dobotlink.M1.GetJOGJointParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_jogcoordinate_params(self,
+    def set_jogcoordinate_params(self, port_name,
                                  velocity,
                                  acceleration,
                                  is_queued=False):
         return self.__dobotlink.M1.SetJOGCoordinateParams(
-            portName=self.__port_name,
+            portName=port_name,
             velocity=velocity,
             acceleration=acceleration,
             isQueued=is_queued)
 
-    def get_jogcoordinate_params(self, ):
+    def get_jogcoordinate_params(self, port_name):
         return self.__dobotlink.M1.GetJOGCoordinateParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_jogcommon_params(self,
+    def set_jogcommon_params(self, port_name,
                              velocity_ratio,
                              acceleration_ratio,
                              is_queued=False):
         return self.__dobotlink.M1.SetJOGCommonParams(
-            portName=self.__port_name,
+            portName=port_name,
             velocityRatio=velocity_ratio,
             accelerationRatio=acceleration_ratio,
             isQueued=is_queued)
 
-    def get_jogcommon_params(self, ):
+    def get_jogcommon_params(self, port_name):
         return self.__dobotlink.M1.GetJOGCommonParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_jogcmd(self, is_joint, cmd, is_queued):
-        return self.__dobotlink.M1.SetJOGCmd(portName=self.__port_name,
+    def set_jogcmd(self, port_name, is_joint, cmd, is_queued):
+        return self.__dobotlink.M1.SetJOGCmd(portName=port_name,
                                              isJoint=is_joint,
                                              cmd=cmd,
                                              isQueued=is_queued)
 
-    def set_inchmode(self, mode: int):
-        return self.__dobotlink.M1.SetInchMode(portName=self.__port_name,
+    def set_inchmode(self, port_name, mode: int):
+        return self.__dobotlink.M1.SetInchMode(portName=port_name,
                                                mode=mode)
 
-    def get_inchmode(self, ):
-        return self.__dobotlink.M1.GetInchMode(portName=self.__port_name, )
+    def get_inchmode(self, port_name):
+        return self.__dobotlink.M1.GetInchMode(portName=port_name)
 
-    def set_inchparam(self, distance_mm: float, distance_ang: float):
-        return self.__dobotlink.M1.SetInchParam(portName=self.__port_name,
+    def set_inchparam(self, port_name, distance_mm: float, distance_ang: float):
+        return self.__dobotlink.M1.SetInchParam(portName=port_name,
                                                 distanceMM=distance_mm,
                                                 distanceANG=distance_ang)
 
-    def get_inchparam(self, ):
-        return self.__dobotlink.M1.GetInchParam(portName=self.__port_name, )
+    def get_inchparam(self, port_name):
+        return self.__dobotlink.M1.GetInchParam(portName=port_name)
 
-    def set_ptpcmd(self,
+    def set_ptpcmd(self, port_name,
                    ptp_mode,
                    x,
                    y,
@@ -278,7 +274,7 @@ class M1Api(object):
                    r,
                    is_queued=True,
                    iswait_forfinish=True):
-        return self.__dobotlink.M1.SetPTPCmd(portName=self.__port_name,
+        return self.__dobotlink.M1.SetPTPCmd(portName=port_name,
                                              ptpMode=ptp_mode,
                                              x=x,
                                              y=y,
@@ -287,73 +283,73 @@ class M1Api(object):
                                              isQueued=is_queued,
                                              isWaitForFinish=iswait_forfinish)
 
-    def set_ptpjoint_param(self, velocity, acceleration, is_queued=False):
-        return self.__dobotlink.M1.SetPTPJointParams(portName=self.__port_name,
+    def set_ptpjoint_param(self, port_name, velocity, acceleration, is_queued=False):
+        return self.__dobotlink.M1.SetPTPJointParams(portName=port_name,
                                                      velocity=velocity,
                                                      acceleration=acceleration,
                                                      isQueued=is_queued)
 
-    def get_ptpjoint_param(self, ):
+    def get_ptpjoint_param(self, port_name):
         return self.__dobotlink.M1.GetPTPJointParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_ptpcoordinate_params(self,
+    def set_ptpcoordinate_params(self, port_name,
                                  xyz_velocity,
                                  r_velocity,
                                  xyz_acceleration,
                                  r_acceleration,
                                  is_queued=False):
         return self.__dobotlink.M1.SetPTPCoordinateParams(
-            portName=self.__port_name,
+            portName=port_name,
             xyzVelocity=xyz_velocity,
             rVelocity=r_velocity,
             xyzAcceleration=xyz_acceleration,
             rAcceleration=r_acceleration,
             isQueued=is_queued)
 
-    def get_ptpcoordinate_params(self, ):
+    def get_ptpcoordinate_params(self, port_name):
         return self.__dobotlink.M1.GetPTPCoordinateParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_ptpjump_params(self,
+    def set_ptpjump_params(self, port_name,
                            isusing_zlimit,
                            z_limit,
                            jump_height,
                            is_queued=False):
         return self.__dobotlink.M1.SetPTPJumpParams(
-            portName=self.__port_name,
+            portName=port_name,
             isUsingZLimit=isusing_zlimit,
             zLimit=z_limit,
             jumpHeight=jump_height,
             isQueued=is_queued)
 
-    def get_ptpjump_params(self, ):
+    def get_ptpjump_params(self, port_name):
         return self.__dobotlink.M1.GetPTPJumpParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_ptpcommon_params(self,
+    def set_ptpcommon_params(self, port_name,
                              velocity_ratio,
                              acceleration_ratio,
                              is_queued=False):
         return self.__dobotlink.M1.SetPTPCommonParams(
-            portName=self.__port_name,
+            portName=port_name,
             velocityRatio=velocity_ratio,
             accelerationRatio=acceleration_ratio,
             isQueued=is_queued)
 
-    def get_ptpcommon_params(self, ):
+    def get_ptpcommon_params(self, port_name):
         return self.__dobotlink.M1.GetPTPCommonParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_motivation_mode(self, mode: int):
-        return self.__dobotlink.M1.SetMotivationMode(portName=self.__port_name,
+    def set_motivation_mode(self, port_name, mode: int):
+        return self.__dobotlink.M1.SetMotivationMode(portName=port_name,
                                                      mode=mode)
 
-    def get_motivation_mode(self, ):
+    def get_motivation_mode(self, port_name):
         return self.__dobotlink.M1.GetMotivationMode(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_motivate_cmd(self,
+    def set_motivate_cmd(self, port_name,
                          q1,
                          q2,
                          dq1,
@@ -364,7 +360,7 @@ class M1Api(object):
                          iswait_forfinish,
                          time_out=10000):
         return self.__dobotlink.M1.SetMotivateCmd(
-            portName=self.__port_name,
+            portName=port_name,
             q1=q1,
             q2=q2,
             dq1=dq1,
@@ -375,40 +371,40 @@ class M1Api(object):
             isWaitForFinish=iswait_forfinish,
             timeout=time_out)
 
-    def set_motivate_zcmd(self, qz, dqz, ddqz, is_queued: bool,
+    def set_motivate_zcmd(self, port_name, qz, dqz, ddqz, is_queued: bool,
                           iswait_forfinish):
         return self.__dobotlink.M1.SetMotivateZCmd(
-            portName=self.__port_name,
+            portName=port_name,
             qz=qz,
             dqz=dqz,
             ddqz=ddqz,
             isQueued=is_queued,
             isWaitForFinish=iswait_forfinish)
 
-    def get_trajectory(self, count_max, index):
-        return self.__dobotlink.M1.GetTrajectory(portName=self.__port_name,
+    def get_trajectory(self, port_name, count_max, index):
+        return self.__dobotlink.M1.GetTrajectory(portName=port_name,
                                                  countMax=count_max,
                                                  index=index)
 
-    def set_iodo(self, port, level, is_queued=False):
-        return self.__dobotlink.M1.SetIODO(portName=self.__port_name,
+    def set_iodo(self, port_name, port, level, is_queued=False):
+        return self.__dobotlink.M1.SetIODO(portName=port_name,
                                            port=port,
                                            level=level,
                                            isQueued=is_queued)
 
-    def get_iodo(self, port):
-        return self.__dobotlink.M1.GetIODO(portName=self.__port_name,
+    def get_iodo(self, port_name, port):
+        return self.__dobotlink.M1.GetIODO(portName=port_name,
                                            port=port)
 
-    def get_iodi(self, port):
-        return self.__dobotlink.M1.GetIODI(portName=self.__port_name,
+    def get_iodi(self, port_name, port):
+        return self.__dobotlink.M1.GetIODI(portName=port_name,
                                            port=port)
 
-    def get_ioadc(self, port):
-        return self.__dobotlink.M1.GetIOADC(portName=self.__port_name,
+    def get_ioadc(self, port_name, port):
+        return self.__dobotlink.M1.GetIOADC(portName=port_name,
                                             port=port)
 
-    def set_cpparams(self,
+    def set_cpparams(self, port_name,
                      target_acc,
                      junction_vel,
                      isreal_timetrack,
@@ -416,7 +412,7 @@ class M1Api(object):
                      period=None,
                      is_queued=False):
         return self.__dobotlink.M1.SetCPParams(
-            portName=self.__port_name,
+            portName=port_name,
             targetAcc=target_acc,
             junctionVel=junction_vel,
             isRealTimeTrack=isreal_timetrack,
@@ -424,11 +420,11 @@ class M1Api(object):
             period=period,
             isQueued=is_queued)
 
-    def get_cpparams(self, ):
-        return self.__dobotlink.M1.GetCPParams(portName=self.__port_name, )
+    def get_cpparams(self, port_name):
+        return self.__dobotlink.M1.GetCPParams(portName=port_name)
 
-    def set_cpcmd(self, cp_mode, x, y, z, power, is_queued=False):
-        return self.__dobotlink.M1.SetCPCmd(portName=self.__port_name,
+    def set_cpcmd(self, port_name, cp_mode, x, y, z, power, is_queued=False):
+        return self.__dobotlink.M1.SetCPCmd(portName=port_name,
                                             cpMode=cp_mode,
                                             x=x,
                                             y=y,
@@ -436,8 +432,8 @@ class M1Api(object):
                                             power=power,
                                             isQueued=is_queued)
 
-    def set_cplecmd(self, cp_mode, x, y, z, power, is_queued=False):
-        return self.__dobotlink.M1.SetCPLECmd(portName=self.__port_name,
+    def set_cplecmd(self, port_name, cp_mode, x, y, z, power, is_queued=False):
+        return self.__dobotlink.M1.SetCPLECmd(portName=port_name,
                                               cpMode=cp_mode,
                                               x=x,
                                               y=y,
@@ -445,37 +441,37 @@ class M1Api(object):
                                               power=power,
                                               isQueued=is_queued)
 
-    def set_arcparams(self,
+    def set_arcparams(self, port_name,
                       xyz_velocity,
                       r_velocity,
                       xyz_acceleration,
                       r_acceleration,
                       is_queued=False):
         return self.__dobotlink.M1.SetARCParams(
-            portName=self.__port_name,
+            portName=port_name,
             xyzVelocity=xyz_velocity,
             rVelocity=r_velocity,
             xyzAcceleration=xyz_acceleration,
             rAcceleration=r_acceleration,
             isQueued=is_queued)
 
-    def get_arcparams(self, ):
-        return self.__dobotlink.M1.GetARCParams(portName=self.__port_name, )
+    def get_arcparams(self, port_name):
+        return self.__dobotlink.M1.GetARCParams(portName=port_name)
 
-    def set_arccmd(self, cir_point, to_point, is_queued=False):
-        return self.__dobotlink.M1.SetARCCmd(portName=self.__port_name,
+    def set_arccmd(self, port_name, cir_point, to_point, is_queued=False):
+        return self.__dobotlink.M1.SetARCCmd(portName=port_name,
                                              cirPoint=cir_point,
                                              toPoint=to_point,
                                              isQueued=is_queued)
 
-    def set_arcpocmd(self, cir_point, to_point, arc_po, is_queued=False):
-        return self.__dobotlink.M1.SetARCPOCmd(portName=self.__port_name,
+    def set_arcpocmd(self, port_name, cir_point, to_point, arc_po, is_queued=False):
+        return self.__dobotlink.M1.SetARCPOCmd(portName=port_name,
                                                cirPoint=cir_point,
                                                toPoint=to_point,
                                                arcPO=arc_po,
                                                isQueued=is_queued)
 
-    def set_circle_cmd(self,
+    def set_circle_cmd(self, port_name,
                        cir_point,
                        to_point,
                        count,
@@ -483,7 +479,7 @@ class M1Api(object):
                        iswait_forfinish=True,
                        time_out=60000):
         return self.__dobotlink.M1.SetCircleCmd(
-            portName=self.__port_name,
+            portName=port_name,
             cirPoint=cir_point,
             toPoint=to_point,
             count=count,
@@ -491,57 +487,57 @@ class M1Api(object):
             isWaitForFinish=iswait_forfinish,
             timeout=time_out)
 
-    def set_circle_pocmd(self,
+    def set_circle_pocmd(self, port_name,
                          cir_point,
                          to_point,
                          count,
                          circle_po,
                          is_queued=False):
-        return self.__dobotlink.M1.SetCirclePOCmd(portName=self.__port_name,
+        return self.__dobotlink.M1.SetCirclePOCmd(portName=port_name,
                                                   cirPoint=cir_point,
                                                   toPoint=to_point,
                                                   count=count,
                                                   circlePO=circle_po,
                                                   isQueued=is_queued)
 
-    def set_arm_orientation(self, arm_orientation):
+    def set_arm_orientation(self, port_name, arm_orientation):
         return self.__dobotlink.M1.SetArmOrientation(
-            portName=self.__port_name, armOrientation=arm_orientation)
+            portName=port_name, armOrientation=arm_orientation)
 
-    def get_arm_orientation(self, ):
+    def get_arm_orientation(self, port_name):
         return self.__dobotlink.M1.GetArmOrientation(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_waitcmd(self, time_out: int, is_queued=False):
-        return self.__dobotlink.M1.SetWAITCmd(portName=self.__port_name,
+    def set_waitcmd(self, port_name, time_out: int, is_queued=False):
+        return self.__dobotlink.M1.SetWAITCmd(portName=port_name,
                                               timeout=time_out,
                                               isQueued=is_queued)
 
-    def set_safemode_enabled(self, enable):
+    def set_safemode_enabled(self, port_name, enable):
         return self.__dobotlink.M1.SetSafeModeEnabled(
-            portName=self.__port_name, enable=enable)
+            portName=port_name, enable=enable)
 
-    def get_safemode_enabled(self, ):
+    def get_safemode_enabled(self, port_name):
         return self.__dobotlink.M1.GetSafeModeEnabled(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_collision_threshold(self, tor_diffj1, tor_diffj2, tor_diffj3,
+    def set_collision_threshold(self, port_name, tor_diffj1, tor_diffj2, tor_diffj3,
                                 tor_diffj4):
         return self.__dobotlink.M1.SetCollisionThreshold(
-            portName=self.__port_name,
+            portName=port_name,
             torDiffJ1=tor_diffj1,
             torDiffJ2=tor_diffj2,
             torDiffJ3=tor_diffj3,
             torDiffJ4=tor_diffj4)
 
-    def get_collision_threshold(self, ):
+    def get_collision_threshold(self, port_name):
         return self.__dobotlink.M1.GetCollisionThreshold(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_basicdynamic_params(self, zz1, fs1, fv1, zz2, mx2, my2, ia2, fs2,
+    def set_basicdynamic_params(self, port_name, zz1, fs1, fv1, zz2, mx2, my2, ia2, fs2,
                                 fv2):
         return self.__dobotlink.M1.SetBasicDynamicParams(
-            portName=self.__port_name,
+            portName=port_name,
             ZZ1=zz1,
             FS1=fs1,
             FV1=fv1,
@@ -552,63 +548,63 @@ class M1Api(object):
             FS2=fs2,
             FV2=fv2)
 
-    def get_basicdynamic_params(self, ):
+    def get_basicdynamic_params(self, port_name):
         return self.__dobotlink.M1.GetBasicDynamicParams(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_load_params(self, load_params):
-        return self.__dobotlink.M1.SetLoadParams(portName=self.__port_name,
+    def set_load_params(self, port_name, load_params):
+        return self.__dobotlink.M1.SetLoadParams(portName=port_name,
                                                  loadParams=load_params)
 
-    def get_load_params(self, ):
-        return self.__dobotlink.M1.GetLoadParams(portName=self.__port_name, )
+    def get_load_params(self, port_name):
+        return self.__dobotlink.M1.GetLoadParams(portName=port_name)
 
-    def set_safestrategy(self, strategy):
-        return self.__dobotlink.M1.SetSafeStrategy(portName=self.__port_name,
+    def set_safestrategy(self, port_name, strategy):
+        return self.__dobotlink.M1.SetSafeStrategy(portName=port_name,
                                                    strategy=strategy)
 
-    def get_safestrategy(self, ):
-        return self.__dobotlink.M1.GetSafeStrategy(portName=self.__port_name, )
+    def get_safestrategy(self, port_name):
+        return self.__dobotlink.M1.GetSafeStrategy(portName=port_name)
 
-    def set_safeguard_mode(self, mode):
-        return self.__dobotlink.M1.SetSafeGuardMode(portName=self.__port_name,
+    def set_safeguard_mode(self, port_name, mode):
+        return self.__dobotlink.M1.SetSafeGuardMode(portName=port_name,
                                                     mode=mode)
 
-    def get_safeguard_mode(self, ):
+    def get_safeguard_mode(self, port_name):
         return self.__dobotlink.M1.GetSafeGuardMode(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def get_safeguard_status(self, ):
+    def get_safeguard_status(self, port_name):
         return self.__dobotlink.M1.GetSafeGuardStatus(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_lanport_config(self, addr, mask, gateway, dns, isdhcp):
-        return self.__dobotlink.M1.SetLanPortConfig(portName=self.__port_name,
+    def set_lanport_config(self, port_name, addr, mask, gateway, dns, isdhcp):
+        return self.__dobotlink.M1.SetLanPortConfig(portName=port_name,
                                                     addr=addr,
                                                     mask=mask,
                                                     gateway=gateway,
                                                     dns=dns,
                                                     isdhcp=isdhcp)
 
-    def get_lanport_config(self, ):
+    def get_lanport_config(self, port_name):
         return self.__dobotlink.M1.GetLanPortConfig(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_firmware_reboot(self, ):
+    def set_firmware_reboot(self, port_name):
         return self.__dobotlink.M1.SetFirmwareReboot(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_firmware_notifym4mode(self, mode):
+    def set_firmware_notifym4mode(self, port_name, mode):
         return self.__dobotlink.M1.SetFirmwareNotifyM4Mode(
-            portName=self.__port_name, mode=mode)
+            portName=port_name, mode=mode)
 
-    def get_firmware_notifym4mode(self, ):
+    def get_firmware_notifym4mode(self, port_name):
         return self.__dobotlink.M1.GetFirmwareNotifyM4Mode(
-            portName=self.__port_name, )
+            portName=port_name)
 
-    def set_feed_forward(self, value):
-        return self.__dobotlink.M1.SetFeedforward(portName=self.__port_name,
+    def set_feed_forward(self, port_name, value):
+        return self.__dobotlink.M1.SetFeedforward(portName=port_name,
                                                   value=value)
 
-    def get_feed_forward(self, ):
-        return self.__dobotlink.M1.GetFeedforward(portName=self.__port_name, )
+    def get_feed_forward(self, port_name):
+        return self.__dobotlink.M1.GetFeedforward(portName=port_name)
