@@ -6,9 +6,6 @@ from .Magician import MagicianApi
 from .M1 import M1Api
 from .Lite import LiteApi
 
-magician_api = MagicianApi()
-m1_api = M1Api()
-lite_api = LiteApi()
 
 __all__ = ("loggers", "RPCClient", "DobotlinkAdapter", "NetworkError",
-           "magician_api", "m1_api", "lite_api")
+           "MagicianApi", "M1Api", "LiteApi")
